@@ -2,7 +2,7 @@
 """DB-SIG compliant module for communicating with MS SQL servers"""
 
 __author__ = 'Mikhail Denisenko <denisenkom@gmail.com>'
-__version__ = '1.1.3'
+__version__ = '1.2.1'
 
 import logging
 import decimal
@@ -510,6 +510,9 @@ class _Cursor(object):
     def get_proc_return_status(self):
         return self._conn._get_proc_return_status(self)
 
+    def cancel(self):
+        self._conn._cancel(self._session)
+
     def close(self):
         """
         Closes the cursor. The cursor is unusable from this point.
